from enum import Enum


class Version(Enum):
    """
    Available request body versions from PS API.
    """

    DEFAULT = "DEFAULT"  # Used for entities that doesn't have versioning.
    V3_0 = "3.0"
    V3_1 = "3.1"
